//+------------------------------------------------------------------+
//|                                                SignalSimpleK.mqh |
//|                                                2011, krokodilizm |
//+------------------------------------------------------------------+
#property copyright "2011 krokodilizm"
//+------------------------------------------------------------------+
//| include files                                                    |
//+------------------------------------------------------------------+
#include <Expert\ExpertSignal.mqh>
// wizard description start
//+------------------------------------------------------------------------------+
//| Description of the class                                                     |
//| Title=Signal based on krokodilizm's simple entry.                            |
//| Type=SignalAdvanced                                                          |
//| Name=SimpleK                                                                 |
//| Class=CSignalSimpleK                                                         |
//| Page=SignalSimpleK                                                           |
//| Parameter=SignalPips,int,50,Pips to indicate price movement                  |
//+------------------------------------------------------------------------------+
// wizard description end
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| CSignalSimpleK class                                                 |
//| Purpose: A class of a module of trade signals,                   |
//| on, ssn's simple entry algorithm                                 |
//+------------------------------------------------------------------+
class CSignalSimpleK : public CExpertSignal
  {
protected:
   //--- adjusted parameters
   int               m_signalpips;
   double            m_basis_price;
   
public:
   virtual int       ShortCondition();      //checks conditions for sell
   virtual int       LongCondition();       //checks conditions for buy
   
   //--- method of verification of settings
   virtual bool      ValidationSettings();
   
   //--- method of creating the indicator and timeseries
                     CSignalSimpleK();
                     ~CSignalSimpleK();
                     
   //--- methods of setting adjustable parameters
   void              SignalPips(int value)    { m_signalpips=value;             }
   
protected:
   //--- method of initialization of the 'basis' price
   double            InitPrice();
  };
//+------------------------------------------------------------------+
//| Constructor CSignalSimpleK.                                   |
//| INPUT:  no.                                                      |
//| OUTPUT: no.                                                      |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
void CSignalSimpleK::CSignalSimpleK()
  {
   m_used_series=USE_SERIES_OPEN+USE_SERIES_HIGH+USE_SERIES_LOW+USE_SERIES_CLOSE;
//--- setting default values for the oscillator parameters
   m_signalpips  =50;
   m_basis_price = 0.0;
  }
//+------------------------------------------------------------------+
//| Destructor CSignalSimpleK.                                           |
//| INPUT:  no.                                                      |
//| OUTPUT: no.                                                      |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
void CSignalSimpleK::~CSignalSimpleK()
  {
  }
//+------------------------------------------------------------------+
//| Validation settings protected data.                              |
//| INPUT:  no.                                                      |
//| OUTPUT: true-if settings are correct, false otherwise.           |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
bool CSignalSimpleK::ValidationSettings()
  {
//--- validation settings of additional filters
   if(!CExpertSignal::ValidationSettings()) return(false);
//--- initial security check
   if(!MQL5InfoInteger(MQL5_TESTING))
   {
      if(m_account.Login()!=20902)//m_symbol.Bank()!="NordFX"
        {
         printf(__FUNCTION__+": please acquire a license by contacting... ");
         return(false);
        }
     }
//--- ok
   return(true);
  }
double CSignalSimpleK::InitPrice()
   {
      int digits=2,i;
      if(m_symbol.Digits()<=3) digits=0;
      double current=m_symbol.Bid(),normalized=NormalizeDouble(current,digits);
      if(current<normalized)
        {
         for(i=0;i<4;i++)
           {
            if(normalized-i*25*PriceLevelUnit()>=current&&current>=normalized-(i+1)*25*PriceLevelUnit())
              {
               return(normalized-i*25*PriceLevelUnit());
              }
           }
        }
      if(current>normalized)
        {
         for(i=0;i<4;i++)
           {
            if(normalized+i*25*PriceLevelUnit()<=current&&current<=normalized+(i+1)*25*PriceLevelUnit())
              {
               return(normalized+(i+1)*25*PriceLevelUnit());
              }
           }
        }
      return(normalized);
   }
//+------------------------------------------------------------------+
//| Checks conditions for buy                                        |
//| INPUT:  None                                                     |
//| OUTPUT: Vote weight from 0 to 100                                |
//| REMARK: None.                                                    |
//+------------------------------------------------------------------+
int CSignalSimpleK::LongCondition()
  {
  if(m_basis_price==0.0)
    {
      m_basis_price=InitPrice();
      return(0);
    }
  //---
  if(m_basis_price-m_symbol.Bid()>=m_signalpips*PriceLevelUnit())
    {
      m_basis_price=m_symbol.Bid();
      return(100);
    }
      
//--- condition is not satisfied
   return(0);
  }
//+------------------------------------------------------------------+
//| Checks conditions for sell                                       |
//| INPUT:  None                                                     |
//| OUTPUT: Vote weight from 0 to 100                                |
//| REMARK: None.                                                    |
//+------------------------------------------------------------------+
int CSignalSimpleK::ShortCondition()
  {
  if(m_basis_price==0.0)
    {
      m_basis_price=InitPrice();
      return(0);
    }
  //---
  if(m_symbol.Bid()-m_basis_price>=m_signalpips*PriceLevelUnit())
    {
      m_basis_price=m_symbol.Bid();
      return(100);
    }
      
      
//--- condition is not satisfied
   return(0);
  }
//+------------------------------------------------------------------+
